==> vdr-plugin-vodcatcher_0.1.2.orig.tar.gz: vodcatcher-0.1.2/src/ConfigurationStub.h <==
/*
 * vdr-vodcatcher - A plugin for the Linux Video Disk Recorder
 * Copyright (c) 2007 Tobias Grimm <vdr@e-tobi.net>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * $Id: ConfigurationStub.h 6511 2007-11-25 18:20:52Z svntobi $
 *
 */

#ifndef CONFIGURATIONSTUB_H_
#define CONFIGURATIONSTUB_H_

#include "IConfiguration.h"

class ConfigurationStub : public IConfiguration
{
private:
    Item::StreamQuality _playBackQuality;

public:
    const std::string GetCacheDirName() const
    {
        return "";
    }
    const std::string GetSourcesFileName() const
    {
        return "";
    }
    int GetMaxCacheAge() const
    {
        return 0;
    }
    void SetMaxCacheAge(const int age)
    {
    }
    void SetPlayBackQuality(const Item::StreamQuality quality)
    {
        _playBackQuality = quality;
    }
    Item::StreamQuality GetPlayBackQuality() const
    {
        return _playBackQuality;
    }
};

#endif

==> vdr-plugin-vodcatcher_0.2.0.orig.tar.gz: vodcatcher-0.2.0/src/ConfigurationStub.h <==
/*
 * vdr-vodcatcher - A plugin for the Linux Video Disk Recorder
 * Copyright (c) 2007 - 2008 Tobias Grimm <vdr@e-tobi.net>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * $Id: ConfigurationStub.h 7656 2008-08-09 21:07:45Z svntobi $
 *
 */

#ifndef CONFIGURATIONSTUB_H_
#define CONFIGURATIONSTUB_H_

#include "IConfiguration.h"

class ConfigurationStub : public IConfiguration
{
private:
    StreamType _playBackQuality;

public:
    const std::string GetCacheDirName() const
    {
        return "";
    }
    const std::string GetSourcesFileName() const
    {
        return "";
    }
    int GetMaxCacheAge() const
    {
        return 0;
    }
    void SetMaxCacheAge(const int age)
    {
    }
    void SetPlayBackQuality(const StreamType quality)
    {
        _playBackQuality = quality;
    }
    StreamType GetPlayBackQuality() const
    {
        return _playBackQuality;
    }

    MediaPlayerType GetMediaPlayerType() const
    {
    	return Mplayer;
    }

    void SetMediaPlayerType(MediaPlayerType)
    {
    }
};

#endif
